# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.bitmovin_response_list import BitmovinResponseList
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream_filter import StreamFilter
from bitmovin_api_sdk.models.stream_filter_list import StreamFilterList
from bitmovin_api_sdk.encoding.encodings.streams.filters.stream_filter_list_list_query_params import StreamFilterListListQueryParams


class FiltersApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(FiltersApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, stream_filter, **kwargs):
        # type: (string_types, string_types, list, dict) -> StreamFilterList
        """Add Filters to Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param stream_filter: The Filters to be added
        :type stream_filter: list[StreamFilter], required
        :return: List of created stream filters
        :rtype: StreamFilterList
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/filters',
            stream_filter,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=StreamFilterList,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, filter_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Specific Filter from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param filter_id: Id of the filter
        :type filter_id: string_types, required
        :return: Id of the filter
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/filters/{filter_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'filter_id': filter_id},
            type=BitmovinResponse,
            **kwargs
        )

    def delete_all(self, encoding_id, stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponseList
        """Delete All Filters from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :return: List of ids of deleted stream filters
        :rtype: BitmovinResponseList
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/filters',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=BitmovinResponseList,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, StreamFilterListListQueryParams, dict) -> StreamFilterList
        """List the filters of a stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: StreamFilterListListQueryParams
        :return: List of stream filters
        :rtype: StreamFilterList
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/filters',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            type=StreamFilterList,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.notification import Notification
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.finished.finished_api import FinishedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.manifest.notification_list_query_params import NotificationListQueryParams


class ManifestApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ManifestApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.error = ErrorApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.finished = FinishedApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, NotificationListQueryParams, dict) -> Notification
        """List Webhook Notifications (Specific Manifest)

        :param manifest_id: Id of the manifest resource
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: NotificationListQueryParams
        :return: List of Webhook Notifications
        :rtype: Notification
        """

        return self.api_client.get(
            '/notifications/webhooks/encoding/manifest/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=Notification,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.dash_representation import DashRepresentation
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.vtt.vtt_api import VttApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.imsc.imsc_api import ImscApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.sprite.sprite_api import SpriteApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.mp4.mp4_api import Mp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.progressive_webm.progressive_webm_api import ProgressiveWebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.dash_representation_list_query_params import DashRepresentationListQueryParams


class RepresentationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(RepresentationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.vtt = VttApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.imsc = ImscApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sprite = SpriteApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.fmp4 = Fmp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.chunked_text = ChunkedTextApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.cmaf = CmafApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.mp4 = Mp4Api(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.webm = WebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.progressive_webm = ProgressiveWebmApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, manifest_id, period_id, adaptationset_id, query_params=None, **kwargs):
        # type: (string_types, string_types, string_types, DashRepresentationListQueryParams, dict) -> DashRepresentation
        """List all DASH Representations

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DashRepresentationListQueryParams
        :return: Representations of the AdaptationSet
        :rtype: DashRepresentation
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id},
            query_params=query_params,
            pagination_response=True,
            type=DashRepresentation,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.dash_cmaf_representation_list_query_params import DashCmafRepresentationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.hls_manifest import HlsManifest
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.start_manifest_request import StartManifestRequest
from bitmovin_api_sdk.models.task import Task
from bitmovin_api_sdk.encoding.manifests.hls.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.hls.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.manifests.hls.media.media_api import MediaApi
from bitmovin_api_sdk.encoding.manifests.hls.hls_manifest_list_query_params import HlsManifestListQueryParams


class HlsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(HlsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.default = DefaultApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.streams = StreamsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.media = MediaApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, hls_manifest, **kwargs):
        # type: (HlsManifest, dict) -> HlsManifest
        """Create HLS Manifest

        :param hls_manifest: The HLS Manifest to be created
        :type hls_manifest: HlsManifest, required
        :return: Hls manifest
        :rtype: HlsManifest
        """

        return self.api_client.post(
            '/encoding/manifests/hls',
            hls_manifest,
            type=HlsManifest,
            **kwargs
        )

    def delete(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete HLS Manifest

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :return: Id of the input
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/hls/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> HlsManifest
        """HLS Manifest Details

        :param manifest_id: Id of the hls manifest.
        :type manifest_id: string_types, required
        :return: HLS manifest details
        :rtype: HlsManifest
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}',
            path_params={'manifest_id': manifest_id},
            type=HlsManifest,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (HlsManifestListQueryParams, dict) -> HlsManifest
        """List HLS Manifests

        :param query_params: Query parameters
        :type query_params: HlsManifestListQueryParams
        :return: HLS manifests
        :rtype: HlsManifest
        """

        return self.api_client.get(
            '/encoding/manifests/hls',
            query_params=query_params,
            pagination_response=True,
            type=HlsManifest,
            **kwargs
        )

    def start(self, manifest_id, start_manifest_request=None, **kwargs):
        # type: (string_types, StartManifestRequest, dict) -> BitmovinResponse
        """Start HLS Manifest Creation

        :param manifest_id: Id of the HLS manifest.
        :type manifest_id: string_types, required
        :param start_manifest_request: Manifest Startup Options
        :type start_manifest_request: StartManifestRequest
        :return: Id of the manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/start',
            start_manifest_request,
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )

    def status(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> Task
        """HLS Manifest Creation Status

        :param manifest_id: Id of the HLS manifest.
        :type manifest_id: string_types, required
        :return: Status of manifest creation
        :rtype: Task
        """

        return self.api_client.get(
            '/encoding/manifests/hls/{manifest_id}/status',
            path_params={'manifest_id': manifest_id},
            type=Task,
            **kwargs
        )

    def stop(self, manifest_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Stop HLS Manifest Creation

        :param manifest_id: Id of the HLS manifest.
        :type manifest_id: string_types, required
        :return: Id of the HLS manifest
        :rtype: BitmovinResponse
        """

        return self.api_client.post(
            '/encoding/manifests/hls/{manifest_id}/stop',
            path_params={'manifest_id': manifest_id},
            type=BitmovinResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.encoding_template import EncodingTemplate
import pprint
import six


class SimpleEncodingVodJobRequest(object):
    @poscheck_model
    def __init__(self,
                 encoding_template=None,
                 inputs=None,
                 outputs=None,
                 name=None):
        # type: (EncodingTemplate, list[SimpleEncodingVodJobInput], list[SimpleEncodingVodJobOutput], string_types) -> None

        self._encoding_template = None
        self._inputs = list()
        self._outputs = list()
        self._name = None
        self.discriminator = None

        if encoding_template is not None:
            self.encoding_template = encoding_template
        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs
        if name is not None:
            self.name = name

    @property
    def openapi_types(self):
        types = {
            'encoding_template': 'EncodingTemplate',
            'inputs': 'list[SimpleEncodingVodJobInput]',
            'outputs': 'list[SimpleEncodingVodJobOutput]',
            'name': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'encoding_template': 'encodingTemplate',
            'inputs': 'inputs',
            'outputs': 'outputs',
            'name': 'name'
        }
        return attributes

    @property
    def encoding_template(self):
        # type: () -> EncodingTemplate
        """Gets the encoding_template of this SimpleEncodingVodJobRequest.

        The template that will be used for the encoding.

        :return: The encoding_template of this SimpleEncodingVodJobRequest.
        :rtype: EncodingTemplate
        """
        return self._encoding_template

    @encoding_template.setter
    def encoding_template(self, encoding_template):
        # type: (EncodingTemplate) -> None
        """Sets the encoding_template of this SimpleEncodingVodJobRequest.

        The template that will be used for the encoding.

        :param encoding_template: The encoding_template of this SimpleEncodingVodJobRequest.
        :type: EncodingTemplate
        """

        if encoding_template is not None:
            if not isinstance(encoding_template, EncodingTemplate):
                raise TypeError("Invalid type for `encoding_template`, type has to be `EncodingTemplate`")

        self._encoding_template = encoding_template

    @property
    def inputs(self):
        # type: () -> list[SimpleEncodingVodJobInput]
        """Gets the inputs of this SimpleEncodingVodJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api#inputs-outputs) (required)

        :return: The inputs of this SimpleEncodingVodJobRequest.
        :rtype: list[SimpleEncodingVodJobInput]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        # type: (list) -> None
        """Sets the inputs of this SimpleEncodingVodJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api#inputs-outputs) (required)

        :param inputs: The inputs of this SimpleEncodingVodJobRequest.
        :type: list[SimpleEncodingVodJobInput]
        """

        if inputs is not None:
            if not isinstance(inputs, list):
                raise TypeError("Invalid type for `inputs`, type has to be `list[SimpleEncodingVodJobInput]`")

        self._inputs = inputs

    @property
    def outputs(self):
        # type: () -> list[SimpleEncodingVodJobOutput]
        """Gets the outputs of this SimpleEncodingVodJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api#inputs-outputs) (required)

        :return: The outputs of this SimpleEncodingVodJobRequest.
        :rtype: list[SimpleEncodingVodJobOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this SimpleEncodingVodJobRequest.

        Please take a look at the [documentation](https://bitmovin.com/docs/encoding/articles/simple-encoding-api#inputs-outputs) (required)

        :param outputs: The outputs of this SimpleEncodingVodJobRequest.
        :type: list[SimpleEncodingVodJobOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[SimpleEncodingVodJobOutput]`")

        self._outputs = outputs

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this SimpleEncodingVodJobRequest.

        This property will be used for naming the encoding and the manifests.

        :return: The name of this SimpleEncodingVodJobRequest.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this SimpleEncodingVodJobRequest.

        This property will be used for naming the encoding and the manifests.

        :param name: The name of this SimpleEncodingVodJobRequest.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SimpleEncodingVodJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.media_stream import MediaStream
import pprint
import six


class AudioStream(MediaStream):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 position=None,
                 duration=None,
                 codec=None,
                 sample_rate=None,
                 bitrate=None,
                 rate=None,
                 channel_format=None,
                 language=None,
                 hearing_impaired=None):
        # type: (string_types, int, float, string_types, int, string_types, int, string_types, string_types, bool) -> None
        super(AudioStream, self).__init__(id_=id_, position=position, duration=duration, codec=codec)

        self._sample_rate = None
        self._bitrate = None
        self._rate = None
        self._channel_format = None
        self._language = None
        self._hearing_impaired = None
        self.discriminator = None

        if sample_rate is not None:
            self.sample_rate = sample_rate
        if bitrate is not None:
            self.bitrate = bitrate
        if rate is not None:
            self.rate = rate
        if channel_format is not None:
            self.channel_format = channel_format
        if language is not None:
            self.language = language
        if hearing_impaired is not None:
            self.hearing_impaired = hearing_impaired

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AudioStream, self), 'openapi_types'):
            types = getattr(super(AudioStream, self), 'openapi_types')

        types.update({
            'sample_rate': 'int',
            'bitrate': 'string_types',
            'rate': 'int',
            'channel_format': 'string_types',
            'language': 'string_types',
            'hearing_impaired': 'bool'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AudioStream, self), 'attribute_map'):
            attributes = getattr(super(AudioStream, self), 'attribute_map')

        attributes.update({
            'sample_rate': 'sampleRate',
            'bitrate': 'bitrate',
            'rate': 'rate',
            'channel_format': 'channelFormat',
            'language': 'language',
            'hearing_impaired': 'hearingImpaired'
        })
        return attributes

    @property
    def sample_rate(self):
        # type: () -> int
        """Gets the sample_rate of this AudioStream.

        Audio sampling rate in Hz

        :return: The sample_rate of this AudioStream.
        :rtype: int
        """
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, sample_rate):
        # type: (int) -> None
        """Sets the sample_rate of this AudioStream.

        Audio sampling rate in Hz

        :param sample_rate: The sample_rate of this AudioStream.
        :type: int
        """

        if sample_rate is not None:
            if not isinstance(sample_rate, int):
                raise TypeError("Invalid type for `sample_rate`, type has to be `int`")

        self._sample_rate = sample_rate

    @property
    def bitrate(self):
        # type: () -> string_types
        """Gets the bitrate of this AudioStream.

        Bitrate in bps

        :return: The bitrate of this AudioStream.
        :rtype: string_types
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (string_types) -> None
        """Sets the bitrate of this AudioStream.

        Bitrate in bps

        :param bitrate: The bitrate of this AudioStream.
        :type: string_types
        """

        if bitrate is not None:
            if not isinstance(bitrate, string_types):
                raise TypeError("Invalid type for `bitrate`, type has to be `string_types`")

        self._bitrate = bitrate

    @property
    def rate(self):
        # type: () -> int
        """Gets the rate of this AudioStream.

        Bitrate in bps

        :return: The rate of this AudioStream.
        :rtype: int
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (int) -> None
        """Sets the rate of this AudioStream.

        Bitrate in bps

        :param rate: The rate of this AudioStream.
        :type: int
        """

        if rate is not None:
            if not isinstance(rate, int):
                raise TypeError("Invalid type for `rate`, type has to be `int`")

        self._rate = rate

    @property
    def channel_format(self):
        # type: () -> string_types
        """Gets the channel_format of this AudioStream.

        Audio channel format

        :return: The channel_format of this AudioStream.
        :rtype: string_types
        """
        return self._channel_format

    @channel_format.setter
    def channel_format(self, channel_format):
        # type: (string_types) -> None
        """Sets the channel_format of this AudioStream.

        Audio channel format

        :param channel_format: The channel_format of this AudioStream.
        :type: string_types
        """

        if channel_format is not None:
            if not isinstance(channel_format, string_types):
                raise TypeError("Invalid type for `channel_format`, type has to be `string_types`")

        self._channel_format = channel_format

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this AudioStream.

        Language of the stream

        :return: The language of this AudioStream.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this AudioStream.

        Language of the stream

        :param language: The language of this AudioStream.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    @property
    def hearing_impaired(self):
        # type: () -> bool
        """Gets the hearing_impaired of this AudioStream.

        Hearing impaired support

        :return: The hearing_impaired of this AudioStream.
        :rtype: bool
        """
        return self._hearing_impaired

    @hearing_impaired.setter
    def hearing_impaired(self, hearing_impaired):
        # type: (bool) -> None
        """Sets the hearing_impaired of this AudioStream.

        Hearing impaired support

        :param hearing_impaired: The hearing_impaired of this AudioStream.
        :type: bool
        """

        if hearing_impaired is not None:
            if not isinstance(hearing_impaired, bool):
                raise TypeError("Invalid type for `hearing_impaired`, type has to be `bool`")

        self._hearing_impaired = hearing_impaired

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AudioStream, self), "to_dict"):
            result = super(AudioStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.output_type import OutputType
import pprint
import six


class CheckOutputPermissionsResponse(object):
    @poscheck_model
    def __init__(self,
                 output_id=None,
                 output_type=None,
                 path=None,
                 passed=None,
                 failure_reason=None):
        # type: (string_types, OutputType, string_types, bool, string_types) -> None

        self._output_id = None
        self._output_type = None
        self._path = None
        self._passed = None
        self._failure_reason = None
        self.discriminator = None

        if output_id is not None:
            self.output_id = output_id
        if output_type is not None:
            self.output_type = output_type
        if path is not None:
            self.path = path
        if passed is not None:
            self.passed = passed
        if failure_reason is not None:
            self.failure_reason = failure_reason

    @property
    def openapi_types(self):
        types = {
            'output_id': 'string_types',
            'output_type': 'OutputType',
            'path': 'string_types',
            'passed': 'bool',
            'failure_reason': 'string_types'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'output_id': 'outputId',
            'output_type': 'outputType',
            'path': 'path',
            'passed': 'passed',
            'failure_reason': 'failureReason'
        }
        return attributes

    @property
    def output_id(self):
        # type: () -> string_types
        """Gets the output_id of this CheckOutputPermissionsResponse.

        Id of the output for which permissions were checked

        :return: The output_id of this CheckOutputPermissionsResponse.
        :rtype: string_types
        """
        return self._output_id

    @output_id.setter
    def output_id(self, output_id):
        # type: (string_types) -> None
        """Sets the output_id of this CheckOutputPermissionsResponse.

        Id of the output for which permissions were checked

        :param output_id: The output_id of this CheckOutputPermissionsResponse.
        :type: string_types
        """

        if output_id is not None:
            if not isinstance(output_id, string_types):
                raise TypeError("Invalid type for `output_id`, type has to be `string_types`")

        self._output_id = output_id

    @property
    def output_type(self):
        # type: () -> OutputType
        """Gets the output_type of this CheckOutputPermissionsResponse.

        The type of the output for which permissions were checked

        :return: The output_type of this CheckOutputPermissionsResponse.
        :rtype: OutputType
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        # type: (OutputType) -> None
        """Sets the output_type of this CheckOutputPermissionsResponse.

        The type of the output for which permissions were checked

        :param output_type: The output_type of this CheckOutputPermissionsResponse.
        :type: OutputType
        """

        if output_type is not None:
            if not isinstance(output_type, OutputType):
                raise TypeError("Invalid type for `output_type`, type has to be `OutputType`")

        self._output_type = output_type

    @property
    def path(self):
        # type: () -> string_types
        """Gets the path of this CheckOutputPermissionsResponse.

        The path on the storage for which permissions were checked. In AWS S3 terminology, this corresponds to a \"prefix\". An empty string corresponds to the root directory.

        :return: The path of this CheckOutputPermissionsResponse.
        :rtype: string_types
        """
        return self._path

    @path.setter
    def path(self, path):
        # type: (string_types) -> None
        """Sets the path of this CheckOutputPermissionsResponse.

        The path on the storage for which permissions were checked. In AWS S3 terminology, this corresponds to a \"prefix\". An empty string corresponds to the root directory.

        :param path: The path of this CheckOutputPermissionsResponse.
        :type: string_types
        """

        if path is not None:
            if not isinstance(path, string_types):
                raise TypeError("Invalid type for `path`, type has to be `string_types`")

        self._path = path

    @property
    def passed(self):
        # type: () -> bool
        """Gets the passed of this CheckOutputPermissionsResponse.

        Indicates if permissions on the storage are configured correctly to be used as output target by the Bitmovin encoder. If \"false\", *failureReason* will provide additional information.

        :return: The passed of this CheckOutputPermissionsResponse.
        :rtype: bool
        """
        return self._passed

    @passed.setter
    def passed(self, passed):
        # type: (bool) -> None
        """Sets the passed of this CheckOutputPermissionsResponse.

        Indicates if permissions on the storage are configured correctly to be used as output target by the Bitmovin encoder. If \"false\", *failureReason* will provide additional information.

        :param passed: The passed of this CheckOutputPermissionsResponse.
        :type: bool
        """

        if passed is not None:
            if not isinstance(passed, bool):
                raise TypeError("Invalid type for `passed`, type has to be `bool`")

        self._passed = passed

    @property
    def failure_reason(self):
        # type: () -> string_types
        """Gets the failure_reason of this CheckOutputPermissionsResponse.

        Contains nothing if the check succeeded. Otherwise, contains a message explaining why it failed.

        :return: The failure_reason of this CheckOutputPermissionsResponse.
        :rtype: string_types
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        # type: (string_types) -> None
        """Sets the failure_reason of this CheckOutputPermissionsResponse.

        Contains nothing if the check succeeded. Otherwise, contains a message explaining why it failed.

        :param failure_reason: The failure_reason of this CheckOutputPermissionsResponse.
        :type: string_types
        """

        if failure_reason is not None:
            if not isinstance(failure_reason, string_types):
                raise TypeError("Invalid type for `failure_reason`, type has to be `string_types`")

        self._failure_reason = failure_reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckOutputPermissionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.cloud_region import CloudRegion
from bitmovin_api_sdk.models.egress_category import EgressCategory
from bitmovin_api_sdk.models.output_type import OutputType
import pprint
import six


class EgressInformation(object):
    @poscheck_model
    def __init__(self,
                 category=None,
                 bytes_=None,
                 output_type=None,
                 output_region=None):
        # type: (EgressCategory, int, OutputType, CloudRegion) -> None

        self._category = None
        self._bytes = None
        self._output_type = None
        self._output_region = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if bytes_ is not None:
            self.bytes = bytes_
        if output_type is not None:
            self.output_type = output_type
        if output_region is not None:
            self.output_region = output_region

    @property
    def openapi_types(self):
        types = {
            'category': 'EgressCategory',
            'bytes': 'int',
            'output_type': 'OutputType',
            'output_region': 'CloudRegion'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'category': 'category',
            'bytes': 'bytes',
            'output_type': 'outputType',
            'output_region': 'outputRegion'
        }
        return attributes

    @property
    def category(self):
        # type: () -> EgressCategory
        """Gets the category of this EgressInformation.


        :return: The category of this EgressInformation.
        :rtype: EgressCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        # type: (EgressCategory) -> None
        """Sets the category of this EgressInformation.


        :param category: The category of this EgressInformation.
        :type: EgressCategory
        """

        if category is not None:
            if not isinstance(category, EgressCategory):
                raise TypeError("Invalid type for `category`, type has to be `EgressCategory`")

        self._category = category

    @property
    def bytes(self):
        # type: () -> int
        """Gets the bytes of this EgressInformation.

        The number of bytes that have been transferred to the output (required)

        :return: The bytes of this EgressInformation.
        :rtype: int
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes_):
        # type: (int) -> None
        """Sets the bytes of this EgressInformation.

        The number of bytes that have been transferred to the output (required)

        :param bytes_: The bytes of this EgressInformation.
        :type: int
        """

        if bytes_ is not None:
            if not isinstance(bytes_, int):
                raise TypeError("Invalid type for `bytes`, type has to be `int`")

        self._bytes = bytes_

    @property
    def output_type(self):
        # type: () -> OutputType
        """Gets the output_type of this EgressInformation.


        :return: The output_type of this EgressInformation.
        :rtype: OutputType
        """
        return self._output_type

    @output_type.setter
    def output_type(self, output_type):
        # type: (OutputType) -> None
        """Sets the output_type of this EgressInformation.


        :param output_type: The output_type of this EgressInformation.
        :type: OutputType
        """

        if output_type is not None:
            if not isinstance(output_type, OutputType):
                raise TypeError("Invalid type for `output_type`, type has to be `OutputType`")

        self._output_type = output_type

    @property
    def output_region(self):
        # type: () -> CloudRegion
        """Gets the output_region of this EgressInformation.


        :return: The output_region of this EgressInformation.
        :rtype: CloudRegion
        """
        return self._output_region

    @output_region.setter
    def output_region(self, output_region):
        # type: (CloudRegion) -> None
        """Sets the output_region of this EgressInformation.


        :param output_region: The output_region of this EgressInformation.
        :type: CloudRegion
        """

        if output_region is not None:
            if not isinstance(output_region, CloudRegion):
                raise TypeError("Invalid type for `output_region`, type has to be `CloudRegion`")

        self._output_region = output_region

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EgressInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



class CencDrmListQueryParams(object):
    def __init__(self, offset=None, limit=None):
        # type: (int, int) -> None
        super(CencDrmListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit'
        }

        return attributes



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class Vp9DynamicRangeFormat(Enum):
    HLG = "HLG"
    SDR = "SDR"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.srt_statistics import SrtStatistics
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_statistics_list_query_params import SrtStatisticsListQueryParams
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_statistics_list_by_srt_input_id_query_params import SrtStatisticsListBySrtInputIdQueryParams


class SrtApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SrtApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, SrtStatisticsListQueryParams, dict) -> SrtStatistics
        """List Stream Infos of Live Statistics from an Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SrtStatisticsListQueryParams
        :return: List of statistics
        :rtype: SrtStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/{encoding_id}/live-statistics/srt',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=SrtStatistics,
            **kwargs
        )

    def list_by_srt_input_id(self, encoding_id, srt_input_id, query_params=None, **kwargs):
        # type: (string_types, string_types, SrtStatisticsListBySrtInputIdQueryParams, dict) -> SrtStatistics
        """List Statistics For SRT Live Stream Input

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param srt_input_id: Id of the SRT input.
        :type srt_input_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SrtStatisticsListBySrtInputIdQueryParams
        :return: List of statistics
        :rtype: SrtStatistics
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/{encoding_id}/live-statistics/srt/{srt_input_id}',
            path_params={'encoding_id': encoding_id, 'srt_input_id': srt_input_id},
            query_params=query_params,
            pagination_response=True,
            type=SrtStatistics,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SidecarErrorMode(Enum):
    FAIL_ON_ERROR = "FAIL_ON_ERROR"
    CONTINUE_ON_ERROR = "CONTINUE_ON_ERROR"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.burn_in_subtitle_dvb_sub import BurnInSubtitleDvbSub
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.dvbsub.burn_in_subtitle_dvb_sub_list_query_params import BurnInSubtitleDvbSubListQueryParams


class DvbsubApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DvbsubApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, burn_in_subtitle_dvb_sub, **kwargs):
        # type: (string_types, string_types, BurnInSubtitleDvbSub, dict) -> BurnInSubtitleDvbSub
        """Burn-In DVB-SUB Subtitle into Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param burn_in_subtitle_dvb_sub: The Burn-In DVB-SUB Subtitle to be added
        :type burn_in_subtitle_dvb_sub: BurnInSubtitleDvbSub, required
        :return: Subtitle resource
        :rtype: BurnInSubtitleDvbSub
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/dvbsub',
            burn_in_subtitle_dvb_sub,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=BurnInSubtitleDvbSub,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, subtitle_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Burn-In DVB-SUB Subtitle from Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param subtitle_id: Id of the subtitle.
        :type subtitle_id: string_types, required
        :return: Id of the subtitle
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/dvbsub/{subtitle_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'subtitle_id': subtitle_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, subtitle_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BurnInSubtitleDvbSub
        """Get Burn-In DVB-SUB Subtitle Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param subtitle_id: Id of the subtitle.
        :type subtitle_id: string_types, required
        :return: Subtitle
        :rtype: BurnInSubtitleDvbSub
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/dvbsub/{subtitle_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'subtitle_id': subtitle_id},
            type=BurnInSubtitleDvbSub,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, BurnInSubtitleDvbSubListQueryParams, dict) -> BurnInSubtitleDvbSub
        """List the Burn-In DVB-SUB subtitles of a stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: BurnInSubtitleDvbSubListQueryParams
        :return: List of Burn-In DVB-SUB subtitles
        :rtype: BurnInSubtitleDvbSub
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/burn-in-subtitles/dvbsub',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=BurnInSubtitleDvbSub,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.fmp4_api import Fmp4Api
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.fmp4.dash_fmp4_representation_list_query_params import DashFmp4RepresentationListQueryParams



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
import pprint


class Filter(BitmovinResource):

    discriminator_value_class_map = {
        'CROP': 'CropFilter',
        'CONFORM': 'ConformFilter',
        'WATERMARK': 'WatermarkFilter',
        'ENHANCED_WATERMARK': 'EnhancedWatermarkFilter',
        'ROTATE': 'RotateFilter',
        'DEINTERLACE': 'DeinterlaceFilter',
        'ENHANCED_DEINTERLACE': 'EnhancedDeinterlaceFilter',
        'AUDIO_MIX': 'AudioMixFilter',
        'DENOISE_HQDN3D': 'DenoiseHqdn3dFilter',
        'TEXT': 'TextFilter',
        'UNSHARP': 'UnsharpFilter',
        'SCALE': 'ScaleFilter',
        'INTERLACE': 'InterlaceFilter',
        'AUDIO_VOLUME': 'AudioVolumeFilter',
        'EBU_R128_SINGLE_PASS': 'EbuR128SinglePassFilter'
    }

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Filter, self), "to_dict"):
            result = super(Filter, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Filter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CodecConfigType(Enum):
    AAC = "AAC"
    DTS = "DTS"
    DTSX = "DTSX"
    DTS_PASSTHROUGH = "DTS_PASSTHROUGH"
    HE_AAC_V1 = "HE_AAC_V1"
    HE_AAC_V2 = "HE_AAC_V2"
    H264 = "H264"
    H265 = "H265"
    VP9 = "VP9"
    VP8 = "VP8"
    MP2 = "MP2"
    MP3 = "MP3"
    AC3 = "AC3"
    EAC3 = "EAC3"
    DD = "DD"
    DDPLUS = "DDPLUS"
    OPUS = "OPUS"
    VORBIS = "VORBIS"
    MJPEG = "MJPEG"
    AV1 = "AV1"
    DOLBY_ATMOS = "DOLBY_ATMOS"
    H262 = "H262"
    PCM = "PCM"
    WEBVTT = "WEBVTT"
    IMSC = "IMSC"
    DVB_SUBTITLE = "DVB_SUBTITLE"



from bitmovin_api_sdk.encoding.configurations.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.configurations.video.h262.h262_api import H262Api
from bitmovin_api_sdk.encoding.configurations.video.h264.h264_api import H264Api
from bitmovin_api_sdk.encoding.configurations.video.h265.h265_api import H265Api
from bitmovin_api_sdk.encoding.configurations.video.vp8.vp8_api import Vp8Api
from bitmovin_api_sdk.encoding.configurations.video.vp9.vp9_api import Vp9Api
from bitmovin_api_sdk.encoding.configurations.video.av1.av1_api import Av1Api
from bitmovin_api_sdk.encoding.configurations.video.mjpeg.mjpeg_api import MjpegApi



from bitmovin_api_sdk.analytics.analytics_api import AnalyticsApi
from bitmovin_api_sdk.analytics.exports.exports_api import ExportsApi
from bitmovin_api_sdk.analytics.impressions.impressions_api import ImpressionsApi
from bitmovin_api_sdk.analytics.insights.insights_api import InsightsApi
from bitmovin_api_sdk.analytics.metrics.metrics_api import MetricsApi
from bitmovin_api_sdk.analytics.ads.ads_api import AdsApi
from bitmovin_api_sdk.analytics.queries.queries_api import QueriesApi
from bitmovin_api_sdk.analytics.licenses.licenses_api import LicensesApi
from bitmovin_api_sdk.analytics.virtual_licenses.virtual_licenses_api import VirtualLicensesApi
from bitmovin_api_sdk.analytics.outputs.outputs_api import OutputsApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.content_protection import ContentProtection
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.cmaf.contentprotection.content_protection_list_query_params import ContentProtectionListQueryParams


class ContentprotectionApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ContentprotectionApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, period_id, adaptationset_id, representation_id, content_protection, **kwargs):
        # type: (string_types, string_types, string_types, string_types, ContentProtection, dict) -> ContentProtection
        """Add Content Protection to CMAF Representation

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the representation
        :type representation_id: string_types, required
        :param content_protection: The content protection to be added to the CMAF representation
        :type content_protection: ContentProtection, required
        :return: Id of the DRM CMAF representation
        :rtype: ContentProtection
        """

        return self.api_client.post(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/cmaf/{representation_id}/contentprotection',
            content_protection,
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id},
            type=ContentProtection,
            **kwargs
        )

    def delete(self, manifest_id, period_id, adaptationset_id, representation_id, contentprotection_id, **kwargs):
        # type: (string_types, string_types, string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete CMAF Representation Content Protection

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the representation
        :type representation_id: string_types, required
        :param contentprotection_id: Id of the DRM CMAF content protection to be deleted
        :type contentprotection_id: string_types, required
        :return: Id of the CMAF Representation Content Protection
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/cmaf/{representation_id}/contentprotection/{contentprotection_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id, 'contentprotection_id': contentprotection_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, period_id, adaptationset_id, representation_id, contentprotection_id, **kwargs):
        # type: (string_types, string_types, string_types, string_types, string_types, dict) -> ContentProtection
        """CMAF Representation Content Protection Details

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the representation
        :type representation_id: string_types, required
        :param contentprotection_id: Id of the DRM CMAF content protection
        :type contentprotection_id: string_types, required
        :return: CMAF Representation Content Protection details
        :rtype: ContentProtection
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/cmaf/{representation_id}/contentprotection/{contentprotection_id}',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id, 'contentprotection_id': contentprotection_id},
            type=ContentProtection,
            **kwargs
        )

    def list(self, manifest_id, period_id, adaptationset_id, representation_id, query_params=None, **kwargs):
        # type: (string_types, string_types, string_types, string_types, ContentProtectionListQueryParams, dict) -> ContentProtection
        """List all CMAF Representation Content Protections

        :param manifest_id: Id of the manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the period
        :type period_id: string_types, required
        :param adaptationset_id: Id of the adaptation set
        :type adaptationset_id: string_types, required
        :param representation_id: Id of the representation
        :type representation_id: string_types, required
        :param query_params: Query parameters
        :type query_params: ContentProtectionListQueryParams
        :return: List of CMAF Representation Content Protections
        :rtype: ContentProtection
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets/{adaptationset_id}/representations/cmaf/{representation_id}/contentprotection',
            path_params={'manifest_id': manifest_id, 'period_id': period_id, 'adaptationset_id': adaptationset_id, 'representation_id': representation_id},
            query_params=query_params,
            pagination_response=True,
            type=ContentProtection,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsExportStatus(Enum):
    STARTED = "STARTED"
    FINISHED = "FINISHED"
    QUEUED = "QUEUED"
    ERROR = "ERROR"



from bitmovin_api_sdk.encoding.configurations.audio.pcm.pcm_api import PcmApi
from bitmovin_api_sdk.encoding.configurations.audio.pcm.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.audio.pcm.pcm_audio_configuration_list_query_params import PcmAudioConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LimitReferences(Enum):
    DISABLED = "DISABLED"
    DEPTH = "DEPTH"
    CU = "CU"
    DEPTH_AND_CU = "DEPTH_AND_CU"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class VorbisChannelLayout(Enum):
    NONE = "NONE"
    MONO = "MONO"
    CL_STEREO = "STEREO"
    CL_SURROUND = "SURROUND"
    CL_QUAD = "QUAD"
    CL_2_1 = "2.1"
    CL_2_2 = "2.2"
    CL_3_1 = "3.1"
    CL_4_0 = "4.0"
    CL_5_1 = "5.1"
    CL_5_1_BACK = "5.1_BACK"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Scheduling(object):
    @poscheck_model
    def __init__(self,
                 priority=None,
                 prewarmed_encoder_pool_ids=None):
        # type: (int, list[string_types]) -> None

        self._priority = None
        self._prewarmed_encoder_pool_ids = list()
        self.discriminator = None

        if priority is not None:
            self.priority = priority
        if prewarmed_encoder_pool_ids is not None:
            self.prewarmed_encoder_pool_ids = prewarmed_encoder_pool_ids

    @property
    def openapi_types(self):
        types = {
            'priority': 'int',
            'prewarmed_encoder_pool_ids': 'list[string_types]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'priority': 'priority',
            'prewarmed_encoder_pool_ids': 'prewarmedEncoderPoolIds'
        }
        return attributes

    @property
    def priority(self):
        # type: () -> int
        """Gets the priority of this Scheduling.

        Specify the priority of this encoding (0 - 100). Higher numbers mean higher priority. Default is 50.

        :return: The priority of this Scheduling.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        # type: (int) -> None
        """Sets the priority of this Scheduling.

        Specify the priority of this encoding (0 - 100). Higher numbers mean higher priority. Default is 50.

        :param priority: The priority of this Scheduling.
        :type: int
        """

        if priority is not None:
            if priority is not None and priority > 100:
                raise ValueError("Invalid value for `priority`, must be a value less than or equal to `100`")
            if priority is not None and priority < 0:
                raise ValueError("Invalid value for `priority`, must be a value greater than or equal to `0`")
            if not isinstance(priority, int):
                raise TypeError("Invalid type for `priority`, type has to be `int`")

        self._priority = priority

    @property
    def prewarmed_encoder_pool_ids(self):
        # type: () -> list[string_types]
        """Gets the prewarmed_encoder_pool_ids of this Scheduling.

        List of prewarmed encoder pools. If set, prewarmed encoders from pools with these IDs will be used for the encoding if available. The pool IDs will be tried in the order in which they are passed.

        :return: The prewarmed_encoder_pool_ids of this Scheduling.
        :rtype: list[string_types]
        """
        return self._prewarmed_encoder_pool_ids

    @prewarmed_encoder_pool_ids.setter
    def prewarmed_encoder_pool_ids(self, prewarmed_encoder_pool_ids):
        # type: (list) -> None
        """Sets the prewarmed_encoder_pool_ids of this Scheduling.

        List of prewarmed encoder pools. If set, prewarmed encoders from pools with these IDs will be used for the encoding if available. The pool IDs will be tried in the order in which they are passed.

        :param prewarmed_encoder_pool_ids: The prewarmed_encoder_pool_ids of this Scheduling.
        :type: list[string_types]
        """

        if prewarmed_encoder_pool_ids is not None:
            if not isinstance(prewarmed_encoder_pool_ids, list):
                raise TypeError("Invalid type for `prewarmed_encoder_pool_ids`, type has to be `list[string_types]`")

        self._prewarmed_encoder_pool_ids = prewarmed_encoder_pool_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Scheduling):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.player.licenses.licenses_api import LicensesApi
from bitmovin_api_sdk.player.licenses.analytics.analytics_api import AnalyticsApi
from bitmovin_api_sdk.player.licenses.domains.domains_api import DomainsApi
from bitmovin_api_sdk.player.licenses.third_party_licensing.third_party_licensing_api import ThirdPartyLicensingApi
from bitmovin_api_sdk.player.licenses.player_license_list_query_params import PlayerLicenseListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsLicenseErrorDetailsConfig(object):
    @poscheck_model
    def __init__(self,
                 enabled=None,
                 network_explorer_enabled=None):
        # type: (bool, bool) -> None

        self._enabled = None
        self._network_explorer_enabled = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if network_explorer_enabled is not None:
            self.network_explorer_enabled = network_explorer_enabled

    @property
    def openapi_types(self):
        types = {
            'enabled': 'bool',
            'network_explorer_enabled': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'enabled': 'enabled',
            'network_explorer_enabled': 'networkExplorerEnabled'
        }
        return attributes

    @property
    def enabled(self):
        # type: () -> bool
        """Gets the enabled of this AnalyticsLicenseErrorDetailsConfig.

        Are error details enabled on the license

        :return: The enabled of this AnalyticsLicenseErrorDetailsConfig.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        # type: (bool) -> None
        """Sets the enabled of this AnalyticsLicenseErrorDetailsConfig.

        Are error details enabled on the license

        :param enabled: The enabled of this AnalyticsLicenseErrorDetailsConfig.
        :type: bool
        """

        if enabled is not None:
            if not isinstance(enabled, bool):
                raise TypeError("Invalid type for `enabled`, type has to be `bool`")

        self._enabled = enabled

    @property
    def network_explorer_enabled(self):
        # type: () -> bool
        """Gets the network_explorer_enabled of this AnalyticsLicenseErrorDetailsConfig.

        Is network explorer feature enabled for the license

        :return: The network_explorer_enabled of this AnalyticsLicenseErrorDetailsConfig.
        :rtype: bool
        """
        return self._network_explorer_enabled

    @network_explorer_enabled.setter
    def network_explorer_enabled(self, network_explorer_enabled):
        # type: (bool) -> None
        """Sets the network_explorer_enabled of this AnalyticsLicenseErrorDetailsConfig.

        Is network explorer feature enabled for the license

        :param network_explorer_enabled: The network_explorer_enabled of this AnalyticsLicenseErrorDetailsConfig.
        :type: bool
        """

        if network_explorer_enabled is not None:
            if not isinstance(network_explorer_enabled, bool):
                raise TypeError("Invalid type for `network_explorer_enabled`, type has to be `bool`")

        self._network_explorer_enabled = network_explorer_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsLicenseErrorDetailsConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions import WebhookNotificationWithStreamConditions
from bitmovin_api_sdk.models.webhook_notification_with_stream_conditions_request import WebhookNotificationWithStreamConditionsRequest


class LiveInputStreamChangedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveInputStreamChangedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Add Live Input Stream Changed Webhook Notification (All Encodings)

        :param webhook_notification_with_stream_conditions_request: The webhook notifications object
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/live-input-stream-changed',
            webhook_notification_with_stream_conditions_request,
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )

    def create_by_encoding_id(self, encoding_id, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (string_types, WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Add Live Input Stream Changed Webhook Notification (Specific Encoding)

        :param encoding_id: Id of the encoding resource
        :type encoding_id: string_types, required
        :param webhook_notification_with_stream_conditions_request: The webhook notifications object
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.post(
            '/notifications/webhooks/encoding/encodings/{encoding_id}/live-input-stream-changed',
            webhook_notification_with_stream_conditions_request,
            path_params={'encoding_id': encoding_id},
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )

    def update(self, notification_id, webhook_notification_with_stream_conditions_request, **kwargs):
        # type: (string_types, WebhookNotificationWithStreamConditionsRequest, dict) -> WebhookNotificationWithStreamConditions
        """Replace Live Input Stream Changed Webhook Notification

        :param notification_id: Id of the webhook notification
        :type notification_id: string_types, required
        :param webhook_notification_with_stream_conditions_request: The webhook notification with the updated values
        :type webhook_notification_with_stream_conditions_request: WebhookNotificationWithStreamConditionsRequest, required
        :return: Notification Details
        :rtype: WebhookNotificationWithStreamConditions
        """

        return self.api_client.put(
            '/notifications/webhooks/encoding/encodings/live-input-stream-changed/{notification_id}',
            webhook_notification_with_stream_conditions_request,
            path_params={'notification_id': notification_id},
            type=WebhookNotificationWithStreamConditions,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class MuxingInformationAudioTrack(object):
    @poscheck_model
    def __init__(self,
                 index=None,
                 codec=None,
                 codec_iso=None,
                 bit_rate=None,
                 rate=None,
                 sample_rate=None,
                 channels=None,
                 duration=None):
        # type: (int, string_types, string_types, int, int, int, int, float) -> None

        self._index = None
        self._codec = None
        self._codec_iso = None
        self._bit_rate = None
        self._rate = None
        self._sample_rate = None
        self._channels = None
        self._duration = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if codec is not None:
            self.codec = codec
        if codec_iso is not None:
            self.codec_iso = codec_iso
        if bit_rate is not None:
            self.bit_rate = bit_rate
        if rate is not None:
            self.rate = rate
        if sample_rate is not None:
            self.sample_rate = sample_rate
        if channels is not None:
            self.channels = channels
        if duration is not None:
            self.duration = duration

    @property
    def openapi_types(self):
        types = {
            'index': 'int',
            'codec': 'string_types',
            'codec_iso': 'string_types',
            'bit_rate': 'int',
            'rate': 'int',
            'sample_rate': 'int',
            'channels': 'int',
            'duration': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'index': 'index',
            'codec': 'codec',
            'codec_iso': 'codecIso',
            'bit_rate': 'bitRate',
            'rate': 'rate',
            'sample_rate': 'sampleRate',
            'channels': 'channels',
            'duration': 'duration'
        }
        return attributes

    @property
    def index(self):
        # type: () -> int
        """Gets the index of this MuxingInformationAudioTrack.

        The stream index in the container

        :return: The index of this MuxingInformationAudioTrack.
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        # type: (int) -> None
        """Sets the index of this MuxingInformationAudioTrack.

        The stream index in the container

        :param index: The index of this MuxingInformationAudioTrack.
        :type: int
        """

        if index is not None:
            if not isinstance(index, int):
                raise TypeError("Invalid type for `index`, type has to be `int`")

        self._index = index

    @property
    def codec(self):
        # type: () -> string_types
        """Gets the codec of this MuxingInformationAudioTrack.

        The codec used for the track

        :return: The codec of this MuxingInformationAudioTrack.
        :rtype: string_types
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (string_types) -> None
        """Sets the codec of this MuxingInformationAudioTrack.

        The codec used for the track

        :param codec: The codec of this MuxingInformationAudioTrack.
        :type: string_types
        """

        if codec is not None:
            if not isinstance(codec, string_types):
                raise TypeError("Invalid type for `codec`, type has to be `string_types`")

        self._codec = codec

    @property
    def codec_iso(self):
        # type: () -> string_types
        """Gets the codec_iso of this MuxingInformationAudioTrack.

        The codec string of the track

        :return: The codec_iso of this MuxingInformationAudioTrack.
        :rtype: string_types
        """
        return self._codec_iso

    @codec_iso.setter
    def codec_iso(self, codec_iso):
        # type: (string_types) -> None
        """Sets the codec_iso of this MuxingInformationAudioTrack.

        The codec string of the track

        :param codec_iso: The codec_iso of this MuxingInformationAudioTrack.
        :type: string_types
        """

        if codec_iso is not None:
            if not isinstance(codec_iso, string_types):
                raise TypeError("Invalid type for `codec_iso`, type has to be `string_types`")

        self._codec_iso = codec_iso

    @property
    def bit_rate(self):
        # type: () -> int
        """Gets the bit_rate of this MuxingInformationAudioTrack.

        The bitrate of the audio track

        :return: The bit_rate of this MuxingInformationAudioTrack.
        :rtype: int
        """
        return self._bit_rate

    @bit_rate.setter
    def bit_rate(self, bit_rate):
        # type: (int) -> None
        """Sets the bit_rate of this MuxingInformationAudioTrack.

        The bitrate of the audio track

        :param bit_rate: The bit_rate of this MuxingInformationAudioTrack.
        :type: int
        """

        if bit_rate is not None:
            if not isinstance(bit_rate, int):
                raise TypeError("Invalid type for `bit_rate`, type has to be `int`")

        self._bit_rate = bit_rate

    @property
    def rate(self):
        # type: () -> int
        """Gets the rate of this MuxingInformationAudioTrack.


        :return: The rate of this MuxingInformationAudioTrack.
        :rtype: int
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        # type: (int) -> None
        """Sets the rate of this MuxingInformationAudioTrack.


        :param rate: The rate of this MuxingInformationAudioTrack.
        :type: int
        """

        if rate is not None:
            if not isinstance(rate, int):
                raise TypeError("Invalid type for `rate`, type has to be `int`")

        self._rate = rate

    @property
    def sample_rate(self):
        # type: () -> int
        """Gets the sample_rate of this MuxingInformationAudioTrack.

        The sampling rate of the audio stream

        :return: The sample_rate of this MuxingInformationAudioTrack.
        :rtype: int
        """
        return self._sample_rate

    @sample_rate.setter
    def sample_rate(self, sample_rate):
        # type: (int) -> None
        """Sets the sample_rate of this MuxingInformationAudioTrack.

        The sampling rate of the audio stream

        :param sample_rate: The sample_rate of this MuxingInformationAudioTrack.
        :type: int
        """

        if sample_rate is not None:
            if not isinstance(sample_rate, int):
                raise TypeError("Invalid type for `sample_rate`, type has to be `int`")

        self._sample_rate = sample_rate

    @property
    def channels(self):
        # type: () -> int
        """Gets the channels of this MuxingInformationAudioTrack.

        The number of channels in this audio stream

        :return: The channels of this MuxingInformationAudioTrack.
        :rtype: int
        """
        return self._channels

    @channels.setter
    def channels(self, channels):
        # type: (int) -> None
        """Sets the channels of this MuxingInformationAudioTrack.

        The number of channels in this audio stream

        :param channels: The channels of this MuxingInformationAudioTrack.
        :type: int
        """

        if channels is not None:
            if not isinstance(channels, int):
                raise TypeError("Invalid type for `channels`, type has to be `int`")

        self._channels = channels

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this MuxingInformationAudioTrack.

        The duration in seconds

        :return: The duration of this MuxingInformationAudioTrack.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this MuxingInformationAudioTrack.

        The duration in seconds

        :param duration: The duration of this MuxingInformationAudioTrack.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MuxingInformationAudioTrack):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AzureCloudRegion(Enum):
    AUSTRALIA_EAST = "AUSTRALIA_EAST"
    AUSTRALIA_SOUTHEAST = "AUSTRALIA_SOUTHEAST"
    EUROPE_NORTH = "EUROPE_NORTH"
    EUROPE_WEST = "EUROPE_WEST"
    GERMANY_WESTCENTRAL = "GERMANY_WESTCENTRAL"
    UAE_NORTH = "UAE_NORTH"
    US_EAST = "US_EAST"
    US_WEST2 = "US_WEST2"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class CaptionCharacterEncoding(Enum):
    ANSI_X3_4_1968 = "ANSI_X3.4-1968"
    ANSI_X3_4_1986 = "ANSI_X3.4-1986"
    ARABIC = "ARABIC"
    ARMSCII_8 = "ARMSCII-8"
    ASCII = "ASCII"
    ASMO_708 = "ASMO-708"
    BIG_5 = "BIG-5"
    BIG_FIVE = "BIG-FIVE"
    BIG5 = "BIG5"
    BIG5_HKSCS = "BIG5-HKSCS"
    BIG5_HKSCS_1999 = "BIG5-HKSCS:1999"
    BIG5_HKSCS_2001 = "BIG5-HKSCS:2001"
    BIG5_HKSCS_2004 = "BIG5-HKSCS:2004"
    BIG5_HKSCS_2008 = "BIG5-HKSCS:2008"
    BIG5HKSCS = "BIG5HKSCS"
    BIGFIVE = "BIGFIVE"
    C99 = "C99"
    CHAR = "CHAR"
    CHINESE = "CHINESE"
    CN = "CN"
    CN_BIG5 = "CN-BIG5"
    CN_GB = "CN-GB"
    CN_GB_ISOIR165 = "CN-GB-ISOIR165"
    CP1131 = "CP1131"
    CP1133 = "CP1133"
    CP1250 = "CP1250"
    CP1251 = "CP1251"
    CP1252 = "CP1252"
    CP1253 = "CP1253"
    CP1254 = "CP1254"
    CP1255 = "CP1255"
    CP1256 = "CP1256"
    CP1257 = "CP1257"
    CP1258 = "CP1258"
    CP1361 = "CP1361"
    CP154 = "CP154"
    CP367 = "CP367"
    CP819 = "CP819"
    CP850 = "CP850"
    CP862 = "CP862"
    CP866 = "CP866"
    CP874 = "CP874"
    CP932 = "CP932"
    CP936 = "CP936"
    CP949 = "CP949"
    CP950 = "CP950"
    CSASCII = "CSASCII"
    CSBIG5 = "CSBIG5"
    CSEUCKR = "CSEUCKR"
    CSEUCPKDFMTJAPANESE = "CSEUCPKDFMTJAPANESE"
    CSEUCTW = "CSEUCTW"
    CSGB2312 = "CSGB2312"
    CSHALFWIDTHKATAKANA = "CSHALFWIDTHKATAKANA"
    CSHPROMAN8 = "CSHPROMAN8"
    CSIBM866 = "CSIBM866"
    CSISO14JISC6220RO = "CSISO14JISC6220RO"
    CSISO159JISX02121990 = "CSISO159JISX02121990"
    CSISO2022CN = "CSISO2022CN"
    CSISO2022JP = "CSISO2022JP"
    CSISO2022JP2 = "CSISO2022JP2"
    CSISO2022KR = "CSISO2022KR"
    CSISO57GB1988 = "CSISO57GB1988"
    CSISO58GB231280 = "CSISO58GB231280"
    CSISO87JISX0208 = "CSISO87JISX0208"
    CSISOLATIN1 = "CSISOLATIN1"
    CSISOLATIN2 = "CSISOLATIN2"
    CSISOLATIN3 = "CSISOLATIN3"
    CSISOLATIN4 = "CSISOLATIN4"
    CSISOLATIN5 = "CSISOLATIN5"
    CSISOLATIN6 = "CSISOLATIN6"
    CSISOLATINARABIC = "CSISOLATINARABIC"
    CSISOLATINCYRILLIC = "CSISOLATINCYRILLIC"
    CSISOLATINGREEK = "CSISOLATINGREEK"
    CSISOLATINHEBREW = "CSISOLATINHEBREW"
    CSKOI8R = "CSKOI8R"
    CSKSC56011987 = "CSKSC56011987"
    CSKZ1048 = "CSKZ1048"
    CSMACINTOSH = "CSMACINTOSH"
    CSPC850MULTILINGUAL = "CSPC850MULTILINGUAL"
    CSPC862LATINHEBREW = "CSPC862LATINHEBREW"
    CSPTCP154 = "CSPTCP154"
    CSSHIFTJIS = "CSSHIFTJIS"
    CSUCS4 = "CSUCS4"
    CSUNICODE = "CSUNICODE"
    CSUNICODE11 = "CSUNICODE11"
    CSUNICODE11UTF7 = "CSUNICODE11UTF7"
    CSVISCII = "CSVISCII"
    CYRILLIC = "CYRILLIC"
    CYRILLIC_ASIAN = "CYRILLIC-ASIAN"
    ECMA_114 = "ECMA-114"
    ECMA_118 = "ECMA-118"
    ELOT_928 = "ELOT_928"
    EUC_CN = "EUC-CN"
    EUC_JP = "EUC-JP"
    EUC_KR = "EUC-KR"
    EUC_TW = "EUC-TW"
    EUCCN = "EUCCN"
    EUCJP = "EUCJP"
    EUCKR = "EUCKR"
    EUCTW = "EUCTW"
    EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE = "EXTENDED_UNIX_CODE_PACKED_FORMAT_FOR_JAPANESE"
    GB_1988_80 = "GB_1988-80"
    GB_2312_80 = "GB_2312-80"
    GB18030 = "GB18030"
    GB2312 = "GB2312"
    GBK = "GBK"
    GEORGIAN_ACADEMY = "GEORGIAN-ACADEMY"
    GEORGIAN_PS = "GEORGIAN-PS"
    GREEK = "GREEK"
    GREEK8 = "GREEK8"
    HEBREW = "HEBREW"
    HP_ROMAN8 = "HP-ROMAN8"
    HZ = "HZ"
    HZ_GB_2312 = "HZ-GB-2312"
    IBM_CP1133 = "IBM-CP1133"
    IBM367 = "IBM367"
    IBM819 = "IBM819"
    IBM850 = "IBM850"
    IBM862 = "IBM862"
    IBM866 = "IBM866"
    ISO_10646_UCS_2 = "ISO-10646-UCS-2"
    ISO_10646_UCS_4 = "ISO-10646-UCS-4"
    ISO_2022_CN = "ISO-2022-CN"
    ISO_2022_CN_EXT = "ISO-2022-CN-EXT"
    ISO_2022_JP = "ISO-2022-JP"
    ISO_2022_JP_1 = "ISO-2022-JP-1"
    ISO_2022_JP_2 = "ISO-2022-JP-2"
    ISO_2022_KR = "ISO-2022-KR"
    ISO_8859_1 = "ISO-8859-1"
    ISO_8859_10 = "ISO-8859-10"
    ISO_8859_11 = "ISO-8859-11"
    ISO_8859_13 = "ISO-8859-13"
    ISO_8859_14 = "ISO-8859-14"
    ISO_8859_15 = "ISO-8859-15"
    ISO_8859_16 = "ISO-8859-16"
    ISO_8859_2 = "ISO-8859-2"
    ISO_8859_3 = "ISO-8859-3"
    ISO_8859_4 = "ISO-8859-4"
    ISO_8859_5 = "ISO-8859-5"
    ISO_8859_6 = "ISO-8859-6"
    ISO_8859_7 = "ISO-8859-7"
    ISO_8859_8 = "ISO-8859-8"
    ISO_8859_9 = "ISO-8859-9"
    ISO_CELTIC = "ISO-CELTIC"
    ISO_IR_100 = "ISO-IR-100"
    ISO_IR_101 = "ISO-IR-101"
    ISO_IR_109 = "ISO-IR-109"
    ISO_IR_110 = "ISO-IR-110"
    ISO_IR_126 = "ISO-IR-126"
    ISO_IR_127 = "ISO-IR-127"
    ISO_IR_138 = "ISO-IR-138"
    ISO_IR_14 = "ISO-IR-14"
    ISO_IR_144 = "ISO-IR-144"
    ISO_IR_148 = "ISO-IR-148"
    ISO_IR_149 = "ISO-IR-149"
    ISO_IR_157 = "ISO-IR-157"
    ISO_IR_159 = "ISO-IR-159"
    ISO_IR_165 = "ISO-IR-165"
    ISO_IR_166 = "ISO-IR-166"
    ISO_IR_179 = "ISO-IR-179"
    ISO_IR_199 = "ISO-IR-199"
    ISO_IR_203 = "ISO-IR-203"
    ISO_IR_226 = "ISO-IR-226"
    ISO_IR_57 = "ISO-IR-57"
    ISO_IR_58 = "ISO-IR-58"
    ISO_IR_6 = "ISO-IR-6"
    ISO_IR_87 = "ISO-IR-87"
    ISO_646_IRV_1991 = "ISO_646.IRV:1991"
    ISO_8859_1_1987 = "ISO_8859-1:1987"
    ISO_8859_10_1992 = "ISO_8859-10:1992"
    ISO_8859_14_1998 = "ISO_8859-14:1998"
    ISO_8859_15_1998 = "ISO_8859-15:1998"
    ISO_8859_16_2001 = "ISO_8859-16:2001"
    ISO_8859_2_1987 = "ISO_8859-2:1987"
    ISO_8859_3_1988 = "ISO_8859-3:1988"
    ISO_8859_4_1988 = "ISO_8859-4:1988"
    ISO_8859_5_1988 = "ISO_8859-5:1988"
    ISO_8859_6_1987 = "ISO_8859-6:1987"
    ISO_8859_7_1987 = "ISO_8859-7:1987"
    ISO_8859_7_2003 = "ISO_8859-7:2003"
    ISO_8859_8_1988 = "ISO_8859-8:1988"
    ISO_8859_9_1989 = "ISO_8859-9:1989"
    ISO646_CN = "ISO646-CN"
    ISO646_JP = "ISO646-JP"
    ISO646_US = "ISO646-US"
    ISO8859_1 = "ISO8859-1"
    ISO8859_10 = "ISO8859-10"
    ISO8859_11 = "ISO8859-11"
    ISO8859_13 = "ISO8859-13"
    ISO8859_14 = "ISO8859-14"
    ISO8859_15 = "ISO8859-15"
    ISO8859_16 = "ISO8859-16"
    ISO8859_2 = "ISO8859-2"
    ISO8859_3 = "ISO8859-3"
    ISO8859_4 = "ISO8859-4"
    ISO8859_5 = "ISO8859-5"
    ISO8859_6 = "ISO8859-6"
    ISO8859_7 = "ISO8859-7"
    ISO8859_8 = "ISO8859-8"
    ISO8859_9 = "ISO8859-9"
    JAVA = "JAVA"
    JIS_C6220_1969_RO = "JIS_C6220-1969-RO"
    JIS_C6226_1983 = "JIS_C6226-1983"
    JIS_X0201 = "JIS_X0201"
    JIS_X0208 = "JIS_X0208"
    JIS_X0208_1983 = "JIS_X0208-1983"
    JIS_X0208_1990 = "JIS_X0208-1990"
    JIS_X0212 = "JIS_X0212"
    JIS_X0212_1990 = "JIS_X0212-1990"
    JIS_X0212_1990_0 = "JIS_X0212.1990-0"
    JIS0208 = "JIS0208"
    JISX0201_1976 = "JISX0201-1976"
    JOHAB = "JOHAB"
    JP = "JP"
    KOI8_R = "KOI8-R"
    KOI8_RU = "KOI8-RU"
    KOI8_T = "KOI8-T"
    KOI8_U = "KOI8-U"
    KOREAN = "KOREAN"
    KS_C_5601_1987 = "KS_C_5601-1987"
    KS_C_5601_1989 = "KS_C_5601-1989"
    KSC_5601 = "KSC_5601"
    KZ_1048 = "KZ-1048"
    L1 = "L1"
    L10 = "L10"
    L2 = "L2"
    L3 = "L3"
    L4 = "L4"
    L5 = "L5"
    L6 = "L6"
    L7 = "L7"
    L8 = "L8"
    LATIN_9 = "LATIN-9"
    LATIN1 = "LATIN1"
    LATIN10 = "LATIN10"
    LATIN2 = "LATIN2"
    LATIN3 = "LATIN3"
    LATIN4 = "LATIN4"
    LATIN5 = "LATIN5"
    LATIN6 = "LATIN6"
    LATIN7 = "LATIN7"
    LATIN8 = "LATIN8"
    MAC = "MAC"
    MACARABIC = "MACARABIC"
    MACCENTRALEUROPE = "MACCENTRALEUROPE"
    MACCROATIAN = "MACCROATIAN"
    MACCYRILLIC = "MACCYRILLIC"
    MACGREEK = "MACGREEK"
    MACHEBREW = "MACHEBREW"
    MACICELAND = "MACICELAND"
    MACINTOSH = "MACINTOSH"
    MACROMAN = "MACROMAN"
    MACROMANIA = "MACROMANIA"
    MACTHAI = "MACTHAI"
    MACTURKISH = "MACTURKISH"
    MACUKRAINE = "MACUKRAINE"
    MS_ANSI = "MS-ANSI"
    MS_ARAB = "MS-ARAB"
    MS_CYRL = "MS-CYRL"
    MS_EE = "MS-EE"
    MS_GREEK = "MS-GREEK"
    MS_HEBR = "MS-HEBR"
    MS_TURK = "MS-TURK"
    MS_KANJI = "MS_KANJI"
    MS936 = "MS936"
    MULELAO_1 = "MULELAO-1"
    NEXTSTEP = "NEXTSTEP"
    PT154 = "PT154"
    PTCP154 = "PTCP154"
    R8 = "R8"
    RK1048 = "RK1048"
    ROMAN8 = "ROMAN8"
    SHIFT_JIS = "SHIFT-JIS"
    SJIS = "SJIS"
    STRK1048_2002 = "STRK1048-2002"
    TCVN = "TCVN"
    TCVN_5712 = "TCVN-5712"
    TCVN5712_1 = "TCVN5712-1"
    TCVN5712_1_1993 = "TCVN5712-1:1993"
    TIS_620 = "TIS-620"
    TIS620 = "TIS620"
    TIS620_0 = "TIS620-0"
    TIS620_2529_1 = "TIS620.2529-1"
    TIS620_2533_0 = "TIS620.2533-0"
    TIS620_2533_1 = "TIS620.2533-1"
    UCS_2 = "UCS-2"
    UCS_2_INTERNAL = "UCS-2-INTERNAL"
    UCS_2_SWAPPED = "UCS-2-SWAPPED"
    UCS_2BE = "UCS-2BE"
    UCS_2LE = "UCS-2LE"
    UCS_4 = "UCS-4"
    UCS_4_INTERNAL = "UCS-4-INTERNAL"
    UCS_4_SWAPPED = "UCS-4-SWAPPED"
    UCS_4BE = "UCS-4BE"
    UCS_4LE = "UCS-4LE"
    UHC = "UHC"
    UNICODE_1_1 = "UNICODE-1-1"
    UNICODE_1_1_UTF_7 = "UNICODE-1-1-UTF-7"
    UNICODEBIG = "UNICODEBIG"
    UNICODELITTLE = "UNICODELITTLE"
    US = "US"
    US_ASCII = "US-ASCII"
    UTF_16 = "UTF-16"
    UTF_16BE = "UTF-16BE"
    UTF_16LE = "UTF-16LE"
    UTF_32 = "UTF-32"
    UTF_32BE = "UTF-32BE"
    UTF_32LE = "UTF-32LE"
    UTF_7 = "UTF-7"
    UTF_8 = "UTF-8"
    VISCII = "VISCII"
    VISCII1_1_1 = "VISCII1.1-1"
    WCHAR_T = "WCHAR_T"
    WINBALTRIM = "WINBALTRIM"
    WINDOWS_1250 = "WINDOWS-1250"
    WINDOWS_1251 = "WINDOWS-1251"
    WINDOWS_1252 = "WINDOWS-1252"
    WINDOWS_1253 = "WINDOWS-1253"
    WINDOWS_1254 = "WINDOWS-1254"
    WINDOWS_1255 = "WINDOWS-1255"
    WINDOWS_1256 = "WINDOWS-1256"
    WINDOWS_1257 = "WINDOWS-1257"
    WINDOWS_1258 = "WINDOWS-1258"
    WINDOWS_874 = "WINDOWS-874"
    WINDOWS_936 = "WINDOWS-936"
    X0201 = "X0201"
    X0208 = "X0208"
    X0212 = "X0212"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingLiveProfile(Enum):
    INCREASED_QUALITY = "INCREASED_QUALITY"
    LOWER_LATENCY = "LOWER_LATENCY"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.dash_manifest_default import DashManifestDefault
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class DefaultApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DefaultApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, dash_manifest_default, **kwargs):
        # type: (DashManifestDefault, dict) -> DashManifestDefault
        """Create DASH Manifest Default

        :param dash_manifest_default: The DASH Manifest Default to be created
        :type dash_manifest_default: DashManifestDefault, required
        :return: Id of the dash manifest
        :rtype: DashManifestDefault
        """

        return self.api_client.post(
            '/encoding/manifests/dash/default',
            dash_manifest_default,
            type=DashManifestDefault,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.rai_unit import RaiUnit
import pprint
import six


class BroadcastTsInputStreamConfiguration(object):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 packet_identifier=None,
                 start_with_discontinuity_indicator=None,
                 align_pes=None,
                 set_rai_on_au=None):
        # type: (string_types, int, bool, bool, RaiUnit) -> None

        self._stream_id = None
        self._packet_identifier = None
        self._start_with_discontinuity_indicator = None
        self._align_pes = None
        self._set_rai_on_au = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if packet_identifier is not None:
            self.packet_identifier = packet_identifier
        if start_with_discontinuity_indicator is not None:
            self.start_with_discontinuity_indicator = start_with_discontinuity_indicator
        if align_pes is not None:
            self.align_pes = align_pes
        if set_rai_on_au is not None:
            self.set_rai_on_au = set_rai_on_au

    @property
    def openapi_types(self):
        types = {
            'stream_id': 'string_types',
            'packet_identifier': 'int',
            'start_with_discontinuity_indicator': 'bool',
            'align_pes': 'bool',
            'set_rai_on_au': 'RaiUnit'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_id': 'streamId',
            'packet_identifier': 'packetIdentifier',
            'start_with_discontinuity_indicator': 'startWithDiscontinuityIndicator',
            'align_pes': 'alignPes',
            'set_rai_on_au': 'setRaiOnAu'
        }
        return attributes

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this BroadcastTsInputStreamConfiguration.

        The UUID of the stream to which this configuration belongs to. This has to be a ID of a stream that has been added to the current muxing.

        :return: The stream_id of this BroadcastTsInputStreamConfiguration.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this BroadcastTsInputStreamConfiguration.

        The UUID of the stream to which this configuration belongs to. This has to be a ID of a stream that has been added to the current muxing.

        :param stream_id: The stream_id of this BroadcastTsInputStreamConfiguration.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def packet_identifier(self):
        # type: () -> int
        """Gets the packet_identifier of this BroadcastTsInputStreamConfiguration.

        An integer value. Packet Identifier (PID) for this stream.

        :return: The packet_identifier of this BroadcastTsInputStreamConfiguration.
        :rtype: int
        """
        return self._packet_identifier

    @packet_identifier.setter
    def packet_identifier(self, packet_identifier):
        # type: (int) -> None
        """Sets the packet_identifier of this BroadcastTsInputStreamConfiguration.

        An integer value. Packet Identifier (PID) for this stream.

        :param packet_identifier: The packet_identifier of this BroadcastTsInputStreamConfiguration.
        :type: int
        """

        if packet_identifier is not None:
            if packet_identifier is not None and packet_identifier > 8190:
                raise ValueError("Invalid value for `packet_identifier`, must be a value less than or equal to `8190`")
            if packet_identifier is not None and packet_identifier < 16:
                raise ValueError("Invalid value for `packet_identifier`, must be a value greater than or equal to `16`")
            if not isinstance(packet_identifier, int):
                raise TypeError("Invalid type for `packet_identifier`, type has to be `int`")

        self._packet_identifier = packet_identifier

    @property
    def start_with_discontinuity_indicator(self):
        # type: () -> bool
        """Gets the start_with_discontinuity_indicator of this BroadcastTsInputStreamConfiguration.

        Start stream with initial discontinuity indicator set to one. If true, set the discontinuity indicator in the first packet for this PID.

        :return: The start_with_discontinuity_indicator of this BroadcastTsInputStreamConfiguration.
        :rtype: bool
        """
        return self._start_with_discontinuity_indicator

    @start_with_discontinuity_indicator.setter
    def start_with_discontinuity_indicator(self, start_with_discontinuity_indicator):
        # type: (bool) -> None
        """Sets the start_with_discontinuity_indicator of this BroadcastTsInputStreamConfiguration.

        Start stream with initial discontinuity indicator set to one. If true, set the discontinuity indicator in the first packet for this PID.

        :param start_with_discontinuity_indicator: The start_with_discontinuity_indicator of this BroadcastTsInputStreamConfiguration.
        :type: bool
        """

        if start_with_discontinuity_indicator is not None:
            if not isinstance(start_with_discontinuity_indicator, bool):
                raise TypeError("Invalid type for `start_with_discontinuity_indicator`, type has to be `bool`")

        self._start_with_discontinuity_indicator = start_with_discontinuity_indicator

    @property
    def align_pes(self):
        # type: () -> bool
        """Gets the align_pes of this BroadcastTsInputStreamConfiguration.

        Align access units to PES packets. If true, align access units to PES packet headers. Uses adaptation field stuffing to position an access unit at the beginning of each PES packet.

        :return: The align_pes of this BroadcastTsInputStreamConfiguration.
        :rtype: bool
        """
        return self._align_pes

    @align_pes.setter
    def align_pes(self, align_pes):
        # type: (bool) -> None
        """Sets the align_pes of this BroadcastTsInputStreamConfiguration.

        Align access units to PES packets. If true, align access units to PES packet headers. Uses adaptation field stuffing to position an access unit at the beginning of each PES packet.

        :param align_pes: The align_pes of this BroadcastTsInputStreamConfiguration.
        :type: bool
        """

        if align_pes is not None:
            if not isinstance(align_pes, bool):
                raise TypeError("Invalid type for `align_pes`, type has to be `bool`")

        self._align_pes = align_pes

    @property
    def set_rai_on_au(self):
        # type: () -> RaiUnit
        """Gets the set_rai_on_au of this BroadcastTsInputStreamConfiguration.


        :return: The set_rai_on_au of this BroadcastTsInputStreamConfiguration.
        :rtype: RaiUnit
        """
        return self._set_rai_on_au

    @set_rai_on_au.setter
    def set_rai_on_au(self, set_rai_on_au):
        # type: (RaiUnit) -> None
        """Sets the set_rai_on_au of this BroadcastTsInputStreamConfiguration.


        :param set_rai_on_au: The set_rai_on_au of this BroadcastTsInputStreamConfiguration.
        :type: RaiUnit
        """

        if set_rai_on_au is not None:
            if not isinstance(set_rai_on_au, RaiUnit):
                raise TypeError("Invalid type for `set_rai_on_au`, type has to be `RaiUnit`")

        self._set_rai_on_au = set_rai_on_au

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsInputStreamConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_digital_plus_dynamic_range_compression import DolbyDigitalPlusDynamicRangeCompression
from bitmovin_api_sdk.models.dolby_digital_plus_lfe_low_pass_filter import DolbyDigitalPlusLfeLowPassFilter
from bitmovin_api_sdk.models.dolby_digital_plus_ninety_degree_phase_shift import DolbyDigitalPlusNinetyDegreePhaseShift
from bitmovin_api_sdk.models.dolby_digital_plus_three_db_attenuation import DolbyDigitalPlusThreeDbAttenuation
import pprint
import six


class DolbyDigitalPlusPreprocessing(object):
    @poscheck_model
    def __init__(self,
                 dynamic_range_compression=None,
                 lfe_low_pass_filter=None,
                 ninety_degree_phase_shift=None,
                 three_db_attenuation=None):
        # type: (DolbyDigitalPlusDynamicRangeCompression, DolbyDigitalPlusLfeLowPassFilter, DolbyDigitalPlusNinetyDegreePhaseShift, DolbyDigitalPlusThreeDbAttenuation) -> None

        self._dynamic_range_compression = None
        self._lfe_low_pass_filter = None
        self._ninety_degree_phase_shift = None
        self._three_db_attenuation = None
        self.discriminator = None

        if dynamic_range_compression is not None:
            self.dynamic_range_compression = dynamic_range_compression
        if lfe_low_pass_filter is not None:
            self.lfe_low_pass_filter = lfe_low_pass_filter
        if ninety_degree_phase_shift is not None:
            self.ninety_degree_phase_shift = ninety_degree_phase_shift
        if three_db_attenuation is not None:
            self.three_db_attenuation = three_db_attenuation

    @property
    def openapi_types(self):
        types = {
            'dynamic_range_compression': 'DolbyDigitalPlusDynamicRangeCompression',
            'lfe_low_pass_filter': 'DolbyDigitalPlusLfeLowPassFilter',
            'ninety_degree_phase_shift': 'DolbyDigitalPlusNinetyDegreePhaseShift',
            'three_db_attenuation': 'DolbyDigitalPlusThreeDbAttenuation'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dynamic_range_compression': 'dynamicRangeCompression',
            'lfe_low_pass_filter': 'lfeLowPassFilter',
            'ninety_degree_phase_shift': 'ninetyDegreePhaseShift',
            'three_db_attenuation': 'threeDbAttenuation'
        }
        return attributes

    @property
    def dynamic_range_compression(self):
        # type: () -> DolbyDigitalPlusDynamicRangeCompression
        """Gets the dynamic_range_compression of this DolbyDigitalPlusPreprocessing.

        It indicates a gain change to be applied in the Dolby Digital decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :return: The dynamic_range_compression of this DolbyDigitalPlusPreprocessing.
        :rtype: DolbyDigitalPlusDynamicRangeCompression
        """
        return self._dynamic_range_compression

    @dynamic_range_compression.setter
    def dynamic_range_compression(self, dynamic_range_compression):
        # type: (DolbyDigitalPlusDynamicRangeCompression) -> None
        """Sets the dynamic_range_compression of this DolbyDigitalPlusPreprocessing.

        It indicates a gain change to be applied in the Dolby Digital decoder in order to implement dynamic range compression.  The values typically indicate gain reductions (cut) during loud passages and gain increases (boost) during quiet passages based on desired compression characteristics. 

        :param dynamic_range_compression: The dynamic_range_compression of this DolbyDigitalPlusPreprocessing.
        :type: DolbyDigitalPlusDynamicRangeCompression
        """

        if dynamic_range_compression is not None:
            if not isinstance(dynamic_range_compression, DolbyDigitalPlusDynamicRangeCompression):
                raise TypeError("Invalid type for `dynamic_range_compression`, type has to be `DolbyDigitalPlusDynamicRangeCompression`")

        self._dynamic_range_compression = dynamic_range_compression

    @property
    def lfe_low_pass_filter(self):
        # type: () -> DolbyDigitalPlusLfeLowPassFilter
        """Gets the lfe_low_pass_filter of this DolbyDigitalPlusPreprocessing.

        It applies a 120 Hz low-pass filter to the low-frequency effects (LFE) channel.  This is only allowed if the `channelLayout` contains a LFE channel. 

        :return: The lfe_low_pass_filter of this DolbyDigitalPlusPreprocessing.
        :rtype: DolbyDigitalPlusLfeLowPassFilter
        """
        return self._lfe_low_pass_filter

    @lfe_low_pass_filter.setter
    def lfe_low_pass_filter(self, lfe_low_pass_filter):
        # type: (DolbyDigitalPlusLfeLowPassFilter) -> None
        """Sets the lfe_low_pass_filter of this DolbyDigitalPlusPreprocessing.

        It applies a 120 Hz low-pass filter to the low-frequency effects (LFE) channel.  This is only allowed if the `channelLayout` contains a LFE channel. 

        :param lfe_low_pass_filter: The lfe_low_pass_filter of this DolbyDigitalPlusPreprocessing.
        :type: DolbyDigitalPlusLfeLowPassFilter
        """

        if lfe_low_pass_filter is not None:
            if not isinstance(lfe_low_pass_filter, DolbyDigitalPlusLfeLowPassFilter):
                raise TypeError("Invalid type for `lfe_low_pass_filter`, type has to be `DolbyDigitalPlusLfeLowPassFilter`")

        self._lfe_low_pass_filter = lfe_low_pass_filter

    @property
    def ninety_degree_phase_shift(self):
        # type: () -> DolbyDigitalPlusNinetyDegreePhaseShift
        """Gets the ninety_degree_phase_shift of this DolbyDigitalPlusPreprocessing.


        :return: The ninety_degree_phase_shift of this DolbyDigitalPlusPreprocessing.
        :rtype: DolbyDigitalPlusNinetyDegreePhaseShift
        """
        return self._ninety_degree_phase_shift

    @ninety_degree_phase_shift.setter
    def ninety_degree_phase_shift(self, ninety_degree_phase_shift):
        # type: (DolbyDigitalPlusNinetyDegreePhaseShift) -> None
        """Sets the ninety_degree_phase_shift of this DolbyDigitalPlusPreprocessing.


        :param ninety_degree_phase_shift: The ninety_degree_phase_shift of this DolbyDigitalPlusPreprocessing.
        :type: DolbyDigitalPlusNinetyDegreePhaseShift
        """

        if ninety_degree_phase_shift is not None:
            if not isinstance(ninety_degree_phase_shift, DolbyDigitalPlusNinetyDegreePhaseShift):
                raise TypeError("Invalid type for `ninety_degree_phase_shift`, type has to be `DolbyDigitalPlusNinetyDegreePhaseShift`")

        self._ninety_degree_phase_shift = ninety_degree_phase_shift

    @property
    def three_db_attenuation(self):
        # type: () -> DolbyDigitalPlusThreeDbAttenuation
        """Gets the three_db_attenuation of this DolbyDigitalPlusPreprocessing.


        :return: The three_db_attenuation of this DolbyDigitalPlusPreprocessing.
        :rtype: DolbyDigitalPlusThreeDbAttenuation
        """
        return self._three_db_attenuation

    @three_db_attenuation.setter
    def three_db_attenuation(self, three_db_attenuation):
        # type: (DolbyDigitalPlusThreeDbAttenuation) -> None
        """Sets the three_db_attenuation of this DolbyDigitalPlusPreprocessing.


        :param three_db_attenuation: The three_db_attenuation of this DolbyDigitalPlusPreprocessing.
        :type: DolbyDigitalPlusThreeDbAttenuation
        """

        if three_db_attenuation is not None:
            if not isinstance(three_db_attenuation, DolbyDigitalPlusThreeDbAttenuation):
                raise TypeError("Invalid type for `three_db_attenuation`, type has to be `DolbyDigitalPlusThreeDbAttenuation`")

        self._three_db_attenuation = three_db_attenuation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DolbyDigitalPlusPreprocessing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_configuration import AudioConfiguration
from bitmovin_api_sdk.models.pcm_channel_layout import PcmChannelLayout
from bitmovin_api_sdk.models.pcm_preset_configuration import PcmPresetConfiguration
from bitmovin_api_sdk.models.pcm_sample_format import PcmSampleFormat
import pprint
import six


class PcmAudioConfiguration(AudioConfiguration):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 bitrate=None,
                 rate=None,
                 preset_configuration=None,
                 channel_layout=None,
                 sample_format=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, float, PcmPresetConfiguration, PcmChannelLayout, PcmSampleFormat) -> None
        super(PcmAudioConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, bitrate=bitrate, rate=rate)

        self._preset_configuration = None
        self._channel_layout = None
        self._sample_format = None
        self.discriminator = None

        if preset_configuration is not None:
            self.preset_configuration = preset_configuration
        if channel_layout is not None:
            self.channel_layout = channel_layout
        if sample_format is not None:
            self.sample_format = sample_format

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PcmAudioConfiguration, self), 'openapi_types'):
            types = getattr(super(PcmAudioConfiguration, self), 'openapi_types')

        types.update({
            'preset_configuration': 'PcmPresetConfiguration',
            'channel_layout': 'PcmChannelLayout',
            'sample_format': 'PcmSampleFormat'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PcmAudioConfiguration, self), 'attribute_map'):
            attributes = getattr(super(PcmAudioConfiguration, self), 'attribute_map')

        attributes.update({
            'preset_configuration': 'presetConfiguration',
            'channel_layout': 'channelLayout',
            'sample_format': 'sampleFormat'
        })
        return attributes

    @property
    def preset_configuration(self):
        # type: () -> PcmPresetConfiguration
        """Gets the preset_configuration of this PcmAudioConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :return: The preset_configuration of this PcmAudioConfiguration.
        :rtype: PcmPresetConfiguration
        """
        return self._preset_configuration

    @preset_configuration.setter
    def preset_configuration(self, preset_configuration):
        # type: (PcmPresetConfiguration) -> None
        """Sets the preset_configuration of this PcmAudioConfiguration.

        Use a set of well defined configurations preset to support certain use cases. Can be overwritten with more specific values.

        :param preset_configuration: The preset_configuration of this PcmAudioConfiguration.
        :type: PcmPresetConfiguration
        """

        if preset_configuration is not None:
            if not isinstance(preset_configuration, PcmPresetConfiguration):
                raise TypeError("Invalid type for `preset_configuration`, type has to be `PcmPresetConfiguration`")

        self._preset_configuration = preset_configuration

    @property
    def channel_layout(self):
        # type: () -> PcmChannelLayout
        """Gets the channel_layout of this PcmAudioConfiguration.

        Channel layout of the audio codec configuration

        :return: The channel_layout of this PcmAudioConfiguration.
        :rtype: PcmChannelLayout
        """
        return self._channel_layout

    @channel_layout.setter
    def channel_layout(self, channel_layout):
        # type: (PcmChannelLayout) -> None
        """Sets the channel_layout of this PcmAudioConfiguration.

        Channel layout of the audio codec configuration

        :param channel_layout: The channel_layout of this PcmAudioConfiguration.
        :type: PcmChannelLayout
        """

        if channel_layout is not None:
            if not isinstance(channel_layout, PcmChannelLayout):
                raise TypeError("Invalid type for `channel_layout`, type has to be `PcmChannelLayout`")

        self._channel_layout = channel_layout

    @property
    def sample_format(self):
        # type: () -> PcmSampleFormat
        """Gets the sample_format of this PcmAudioConfiguration.

        Sampling format of the audio codec configuration

        :return: The sample_format of this PcmAudioConfiguration.
        :rtype: PcmSampleFormat
        """
        return self._sample_format

    @sample_format.setter
    def sample_format(self, sample_format):
        # type: (PcmSampleFormat) -> None
        """Sets the sample_format of this PcmAudioConfiguration.

        Sampling format of the audio codec configuration

        :param sample_format: The sample_format of this PcmAudioConfiguration.
        :type: PcmSampleFormat
        """

        if sample_format is not None:
            if not isinstance(sample_format, PcmSampleFormat):
                raise TypeError("Invalid type for `sample_format`, type has to be `PcmSampleFormat`")

        self._sample_format = sample_format

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PcmAudioConfiguration, self), "to_dict"):
            result = super(PcmAudioConfiguration, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PcmAudioConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.cmaf.cmaf_api import CmafApi
from bitmovin_api_sdk.encoding.encodings.muxings.cmaf.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.cmaf.cmaf_muxing_list_query_params import CmafMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input_stream import InputStream
import pprint
import six


class TimeBasedTrimmingInputStream(InputStream):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_stream_id=None,
                 offset=None,
                 duration=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, float, float) -> None
        super(TimeBasedTrimmingInputStream, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input_stream_id = None
        self._offset = None
        self._duration = None
        self.discriminator = None

        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if offset is not None:
            self.offset = offset
        if duration is not None:
            self.duration = duration

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(TimeBasedTrimmingInputStream, self), 'openapi_types'):
            types = getattr(super(TimeBasedTrimmingInputStream, self), 'openapi_types')

        types.update({
            'input_stream_id': 'string_types',
            'offset': 'float',
            'duration': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(TimeBasedTrimmingInputStream, self), 'attribute_map'):
            attributes = getattr(super(TimeBasedTrimmingInputStream, self), 'attribute_map')

        attributes.update({
            'input_stream_id': 'inputStreamId',
            'offset': 'offset',
            'duration': 'duration'
        })
        return attributes

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this TimeBasedTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :return: The input_stream_id of this TimeBasedTrimmingInputStream.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this TimeBasedTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :param input_stream_id: The input_stream_id of this TimeBasedTrimmingInputStream.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def offset(self):
        # type: () -> float
        """Gets the offset of this TimeBasedTrimmingInputStream.

        Defines the offset in seconds at which the encoding should start, beginning at 0. The frame indicated by this value will be included in the encoding

        :return: The offset of this TimeBasedTrimmingInputStream.
        :rtype: float
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        # type: (float) -> None
        """Sets the offset of this TimeBasedTrimmingInputStream.

        Defines the offset in seconds at which the encoding should start, beginning at 0. The frame indicated by this value will be included in the encoding

        :param offset: The offset of this TimeBasedTrimmingInputStream.
        :type: float
        """

        if offset is not None:
            if offset is not None and offset < 0:
                raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")
            if not isinstance(offset, (float, int)):
                raise TypeError("Invalid type for `offset`, type has to be `float`")

        self._offset = offset

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this TimeBasedTrimmingInputStream.

        Defines how many seconds of the input will be encoded. Not defining or setting it to null indicates that the remaining input (considering offset) will be encoded.

        :return: The duration of this TimeBasedTrimmingInputStream.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this TimeBasedTrimmingInputStream.

        Defines how many seconds of the input will be encoded. Not defining or setting it to null indicates that the remaining input (considering offset) will be encoded.

        :param duration: The duration of this TimeBasedTrimmingInputStream.
        :type: float
        """

        if duration is not None:
            if duration is not None and duration < 0:
                raise ValueError("Invalid value for `duration`, must be a value greater than or equal to `0`")
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(TimeBasedTrimmingInputStream, self), "to_dict"):
            result = super(TimeBasedTrimmingInputStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TimeBasedTrimmingInputStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.position_unit import PositionUnit
import pprint
import six


class EnhancedWatermarkFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 image=None,
                 left=None,
                 right=None,
                 top=None,
                 bottom=None,
                 unit=None,
                 opacity=None,
                 width=None,
                 height=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, float, float, float, float, PositionUnit, float, float, float) -> None
        super(EnhancedWatermarkFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._image = None
        self._left = None
        self._right = None
        self._top = None
        self._bottom = None
        self._unit = None
        self._opacity = None
        self._width = None
        self._height = None
        self.discriminator = None

        if image is not None:
            self.image = image
        if left is not None:
            self.left = left
        if right is not None:
            self.right = right
        if top is not None:
            self.top = top
        if bottom is not None:
            self.bottom = bottom
        if unit is not None:
            self.unit = unit
        if opacity is not None:
            self.opacity = opacity
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(EnhancedWatermarkFilter, self), 'openapi_types'):
            types = getattr(super(EnhancedWatermarkFilter, self), 'openapi_types')

        types.update({
            'image': 'string_types',
            'left': 'float',
            'right': 'float',
            'top': 'float',
            'bottom': 'float',
            'unit': 'PositionUnit',
            'opacity': 'float',
            'width': 'float',
            'height': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(EnhancedWatermarkFilter, self), 'attribute_map'):
            attributes = getattr(super(EnhancedWatermarkFilter, self), 'attribute_map')

        attributes.update({
            'image': 'image',
            'left': 'left',
            'right': 'right',
            'top': 'top',
            'bottom': 'bottom',
            'unit': 'unit',
            'opacity': 'opacity',
            'width': 'width',
            'height': 'height'
        })
        return attributes

    @property
    def image(self):
        # type: () -> string_types
        """Gets the image of this EnhancedWatermarkFilter.

        URL of the file to be used as watermark image. Supported image formats: PNG, JPEG, BMP, GIF (required)

        :return: The image of this EnhancedWatermarkFilter.
        :rtype: string_types
        """
        return self._image

    @image.setter
    def image(self, image):
        # type: (string_types) -> None
        """Sets the image of this EnhancedWatermarkFilter.

        URL of the file to be used as watermark image. Supported image formats: PNG, JPEG, BMP, GIF (required)

        :param image: The image of this EnhancedWatermarkFilter.
        :type: string_types
        """

        if image is not None:
            if not isinstance(image, string_types):
                raise TypeError("Invalid type for `image`, type has to be `string_types`")

        self._image = image

    @property
    def left(self):
        # type: () -> float
        """Gets the left of this EnhancedWatermarkFilter.

        Distance from the left edge of the input video to the left edge of the watermark image. May not be set if 'right' is set.

        :return: The left of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._left

    @left.setter
    def left(self, left):
        # type: (float) -> None
        """Sets the left of this EnhancedWatermarkFilter.

        Distance from the left edge of the input video to the left edge of the watermark image. May not be set if 'right' is set.

        :param left: The left of this EnhancedWatermarkFilter.
        :type: float
        """

        if left is not None:
            if not isinstance(left, (float, int)):
                raise TypeError("Invalid type for `left`, type has to be `float`")

        self._left = left

    @property
    def right(self):
        # type: () -> float
        """Gets the right of this EnhancedWatermarkFilter.

        Distance from the right edge of the input video to the right edge of the watermark image . May not be set if 'left' is set.

        :return: The right of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._right

    @right.setter
    def right(self, right):
        # type: (float) -> None
        """Sets the right of this EnhancedWatermarkFilter.

        Distance from the right edge of the input video to the right edge of the watermark image . May not be set if 'left' is set.

        :param right: The right of this EnhancedWatermarkFilter.
        :type: float
        """

        if right is not None:
            if not isinstance(right, (float, int)):
                raise TypeError("Invalid type for `right`, type has to be `float`")

        self._right = right

    @property
    def top(self):
        # type: () -> float
        """Gets the top of this EnhancedWatermarkFilter.

        Distance from the top edge of the input video to the top edge of the watermark image. May not be set if 'bottom' is set.

        :return: The top of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._top

    @top.setter
    def top(self, top):
        # type: (float) -> None
        """Sets the top of this EnhancedWatermarkFilter.

        Distance from the top edge of the input video to the top edge of the watermark image. May not be set if 'bottom' is set.

        :param top: The top of this EnhancedWatermarkFilter.
        :type: float
        """

        if top is not None:
            if not isinstance(top, (float, int)):
                raise TypeError("Invalid type for `top`, type has to be `float`")

        self._top = top

    @property
    def bottom(self):
        # type: () -> float
        """Gets the bottom of this EnhancedWatermarkFilter.

        Distance from the bottom edge of the input video to the bottom edge of the watermark image. May not be set if 'top' is set.

        :return: The bottom of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._bottom

    @bottom.setter
    def bottom(self, bottom):
        # type: (float) -> None
        """Sets the bottom of this EnhancedWatermarkFilter.

        Distance from the bottom edge of the input video to the bottom edge of the watermark image. May not be set if 'top' is set.

        :param bottom: The bottom of this EnhancedWatermarkFilter.
        :type: float
        """

        if bottom is not None:
            if not isinstance(bottom, (float, int)):
                raise TypeError("Invalid type for `bottom`, type has to be `float`")

        self._bottom = bottom

    @property
    def unit(self):
        # type: () -> PositionUnit
        """Gets the unit of this EnhancedWatermarkFilter.


        :return: The unit of this EnhancedWatermarkFilter.
        :rtype: PositionUnit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        # type: (PositionUnit) -> None
        """Sets the unit of this EnhancedWatermarkFilter.


        :param unit: The unit of this EnhancedWatermarkFilter.
        :type: PositionUnit
        """

        if unit is not None:
            if not isinstance(unit, PositionUnit):
                raise TypeError("Invalid type for `unit`, type has to be `PositionUnit`")

        self._unit = unit

    @property
    def opacity(self):
        # type: () -> float
        """Gets the opacity of this EnhancedWatermarkFilter.

        Opacity to apply on the watermark image. Valid values are from 0.0 (completely transparent) to 1.0 (not transparent at all)

        :return: The opacity of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._opacity

    @opacity.setter
    def opacity(self, opacity):
        # type: (float) -> None
        """Sets the opacity of this EnhancedWatermarkFilter.

        Opacity to apply on the watermark image. Valid values are from 0.0 (completely transparent) to 1.0 (not transparent at all)

        :param opacity: The opacity of this EnhancedWatermarkFilter.
        :type: float
        """

        if opacity is not None:
            if not isinstance(opacity, (float, int)):
                raise TypeError("Invalid type for `opacity`, type has to be `float`")

        self._opacity = opacity

    @property
    def width(self):
        # type: () -> float
        """Gets the width of this EnhancedWatermarkFilter.

        Desired width of the watermark image, the unit of the parameter is specified separately by the parameter 'unit'. If both width and height are set the watermark size is fixed. If only one is set the aspect ratio of the image will be used to rescale it

        :return: The width of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (float) -> None
        """Sets the width of this EnhancedWatermarkFilter.

        Desired width of the watermark image, the unit of the parameter is specified separately by the parameter 'unit'. If both width and height are set the watermark size is fixed. If only one is set the aspect ratio of the image will be used to rescale it

        :param width: The width of this EnhancedWatermarkFilter.
        :type: float
        """

        if width is not None:
            if not isinstance(width, (float, int)):
                raise TypeError("Invalid type for `width`, type has to be `float`")

        self._width = width

    @property
    def height(self):
        # type: () -> float
        """Gets the height of this EnhancedWatermarkFilter.

        Desired height of the watermark image, the unit of the parameter is specified separately by the parameter 'unit'. If both width and height are set the watermark size is fixed. If only one is set the aspect ratio of the image will be used to rescale it

        :return: The height of this EnhancedWatermarkFilter.
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (float) -> None
        """Sets the height of this EnhancedWatermarkFilter.

        Desired height of the watermark image, the unit of the parameter is specified separately by the parameter 'unit'. If both width and height are set the watermark size is fixed. If only one is set the aspect ratio of the image will be used to rescale it

        :param height: The height of this EnhancedWatermarkFilter.
        :type: float
        """

        if height is not None:
            if not isinstance(height, (float, int)):
                raise TypeError("Invalid type for `height`, type has to be `float`")

        self._height = height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(EnhancedWatermarkFilter, self), "to_dict"):
            result = super(EnhancedWatermarkFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnhancedWatermarkFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.finished.finished_api import FinishedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.error_api import ErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.transfer_error_api import TransferErrorApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.encoding_status_changed.encoding_status_changed_api import EncodingStatusChangedApi
